==> haskell-comonad-5.0.9-120.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 comonad
version:              5.0.9
visibility:           public
id:                   comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot
key:                  comonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot
license:              BSD-3-Clause
copyright:
    Copyright (C) 2008-2014 Edward A. Kmett,
    Copyright (C) 2004-2008 Dave Menendez

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/comonad/
synopsis:             Comonads
description:          Comonads.
category:             Control, Comonads
abi:                  c68a69b8c67db3a9fd3d6da609a21da3
exposed:              True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition

import-dirs:          /usr/lib/ghc-9.6.6/site-local/comonad-5.0.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/comonad-5.0.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/comonad-5.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-comonad
hs-libraries:         HScomonad-5.0.9-5bfOfNZGuHK7Og8aLM6Xot
depends:
    base-4.18.2.1 containers-0.6.7
    distributive-0.6.2.1-L1zs4X1vyqcJbGQmd1YXaS
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:   /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html:         /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-comonad-5.0.9-121-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 comonad
version:              5.0.9
visibility:           public
id:                   comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL
key:                  comonad-5.0.9-715y3Qio4tKCm1VNZVBtRL
license:              BSD-3-Clause
copyright:
    Copyright (C) 2008-2014 Edward A. Kmett,
    Copyright (C) 2004-2008 Dave Menendez

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/comonad/
synopsis:             Comonads
description:          Comonads.
category:             Control, Comonads
abi:                  fd97952142bdae094c3ac30486bcb9db
exposed:              True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition

import-dirs:          /usr/lib/ghc-9.6.6/site-local/comonad-5.0.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/comonad-5.0.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/comonad-5.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-comonad
hs-libraries:         HScomonad-5.0.9-715y3Qio4tKCm1VNZVBtRL
depends:
    base-4.18.2.1 containers-0.6.7
    distributive-0.6.2.1-GSLXrb3mYHCCnRW3oVJKQJ
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig transformers-0.6.1.0
    transformers-compat-0.7.2-LmnlcpbfHuuAOWEWPuyobH

haddock-interfaces:   /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html:         /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
